=======
History
=======

0.1.2 (2019-05-02)
------------------

* Remove Python 2 compatibility

0.1.1 (2017-03-15)
------------------

* Minor functionality update:
    - `unique_keys`
    - `to_tree_string`
    - Improved filtering/indexing
    - Documentation


0.1.0 (2017-03-14)
------------------

* Initial Version with basic functionality
